#! /usr/bin/env bash

alias @arvan=bluer_sandbox_arvancloud
alias @arvancloud=bluer_sandbox_arvancloud

alias @assets=bluer_sandbox_assets

alias @docker=bluer_sandbox_docker

alias @offline_llm=bluer_sandbox_offline_llm

alias @notebooks=bluer_sandbox_notebooks

alias @sandbox=bluer_sandbox

alias @speedtest=bluer_sandbox_speedtest
